<?php

namespace Drupal\Tests\google_optimize_js\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * A test that ensures that the JS snippets are conditionally rendered.
 *
 * @group google_optimize_js
 */
class FrontendTest extends BrowserTestBase {

  /**
   * {@inheritDoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritDoc}
   */
  protected static $modules = [
    'google_optimize_js',
  ];

  /**
   * Tests that javascript is rendered on the front end appropriately.
   */
  public function testFrontend() {

    // No scripts should render without being configured.
    $this->drupalGet(Url::fromRoute('<front>'));
    $page_content = $this->getSession()->getPage()->getContent();

    $this->assertStringNotContainsString('https://www.googleoptimize.com/optimize.js?id=GTM-XXXXX', $page_content);
    $this->assertStringNotContainsString('a,s,y,n,c,h,i,d,e', $page_content);

    /* @var $config_factory \Drupal\Core\Config\ConfigFactoryInterface */
    $config_factory = $this->container->get('config.factory');

    $config_factory->getEditable('google_optimize_js.settings')
      ->set('container', 'GTM-XXXXX')
      ->set('enabled', TRUE)
      ->set('anti_flicker_pages', '<front>')
      ->save();

    // Scripts should render after being configured to.
    $this->drupalGet(Url::fromRoute('<front>'));
    $page_content = $this->getSession()->getPage()->getContent();

    $this->assertStringContainsString('https://www.googleoptimize.com/optimize.js?id=GTM-XXXXX', $page_content);
    $this->assertStringContainsString('a,s,y,n,c,h,i,d,e', $page_content);
  }

}
